#ifndef SERVERS_H__
#define SERVERS_H__


struct server_t {
  struct server_t 	*next;
  gchar			*hostname;	/* the hostname of a server */
  gint			port;		/* tcp port */
  gboolean		autoconnect;	/* guess what? */
};

typedef struct server_t SilkyServer;

gboolean init_servers(gchar *serverspath);
gboolean parse_servers();

SilkyServer *server_find_by_hostport(gchar *host, gint port);
SilkyServer *server_add(gchar *host, gint port);

gboolean server_remove( SilkyServer *server );

gboolean servers_store_to_xml();


#endif
